@@ -48,10 +48,10 @@ if [ -x "/etc/init.d/benno-archive" ]; then
 	#fi
     # Get System Info
     echo -n "Wait for archive "
-    for i  in 1 1 2 2 2 2; do
+    for i  in 1 1 2 2 2 2 5 5 5 5 10 10; do
         echo -n "."
         SYSTEMINFO=$(/bin/echo -e 'show info\nquit'|nc localhost 2555 2>/dev/null)
-        if [ "${SYSTEMINFO}x" != x ];then break; fi
+        if echo "${SYSTEMINFO}"|grep -q bennocore; then break; fi
         sleep $i
     done
     echo ""
